==> potamia-config-wireless-1.0.1.050808.tar.gz: booyo-wireless/frontend/potamia-config-wireless.py <==
#!/usr/bin/env python

import pygtk
pygtk.require('2.0')
import sys
import gtk
import gobject

#PATH = '../'
PATH = '/usr/share/potamia-config-wireless/'

sys.path.append(PATH + 'frontend')
sys.path.append(PATH + 'backend')
import gui_profile
import gui_ap
#import gui_status

PROGNAME='potamia-config-wireless'

import locale
from rhpl.translate import _, N_, textdomain_codeset
locale.setlocale(locale.LC_ALL, "")
textdomain_codeset(PROGNAME, locale.nl_langinfo(locale.CODESET))

import __builtin__
__builtin__.__dict__['_'] = _

class BooyoAPMenu:
    # This is the ItemFactoryEntry structure used to generate new menus.
    # Item 1: The menu path. The letter after the underscore indicates an
    #         accelerator key once the menu is open.
    # Item 2: The accelerator key for the entry
    # Item 3: The callback.
    # Item 4: The callback action.  This changes the parameters with
    #         which the callback is called.  The default is 0.
    # Item 5: The item type, used to define what kind of an item it is.
    #       Here are the possible values:

    #       NULL               -> "<Item>"
    #       ""                 -> "<Item>"
    #       "<Title>"          -> create a title item
    #       "<Item>"           -> create a simple item
    #       "<CheckItem>"      -> create a check item
    #       "<ToggleItem>"     -> create a toggle item
    #       "<RadioItem>"      -> create a radio item
    #       <path>             -> path of a radio item to link against
    #       "<Separator>"      -> create a separator
    #       "<Branch>"         -> create an item to hold sub items (optional)
    #       "<LastBranch>"     -> create a right justified branch 

    def get_main_menu(self, window):
        accel_group = gtk.AccelGroup()

        # This function initializes the item factory.
        # Param 1: The type of menu - can be MenuBar, Menu,
        #          or OptionMenu.
        # Param 2: The path of the menu.
        # Param 3: A reference to an AccelGroup. The item factory sets up
        #          the accelerator table while generating menus.
        item_factory = gtk.ItemFactory(gtk.MenuBar, "<main>", accel_group)

        # This method generates the menu items. Pass to the item factory
        #  the list of menu items
        item_factory.create_items(self.menu_items)

        # Attach the new accelerator group to the window.
        window.add_accel_group(accel_group)

        # need to keep a reference to item_factory to prevent its destruction
        self.item_factory = item_factory
        # Finally, return the actual menu bar created by the item factory.
        return item_factory.get_widget("<main>")

    def __init__(self):
        self.menu_items = (
            ( '/'+_('_File'),         		None,         	None, 0, "<Branch>" ),
            ( '/'+_('_File')+'/'+'sep1',	None,         	None, 0, "<Separator>" ),
            ( '/'+_('_File')+'/'+_('Quit'),     "<control>Q",	gtk.main_quit, 0, None ),
            ( '/'+_('_Help'),      		None,		None, 0, "<Branch>" ),
#            ( "/Help/Help",   			None,         	self.print_help, 0, None ),
#            ( "/Help/sep1",    		None,         	None, 0, "<Separator>" ),
	    ( '/'+_('_Help')+'/'+_('About'),	None,         	self.print_about, 0, None )
#            ( "/About/sep2",    		None,         	None, 0, "<Separator>" ),
#            ( "/About/Version", 		None,         	self.print_version, 0, None ),
            )
        window = gtk.Window(gtk.WINDOW_TOPLEVEL)
	window.set_position(gtk.WIN_POS_CENTER_ALWAYS)
        window.connect("destroy", lambda w: gtk.main_quit())
	# window title name setting
	title = _('AP Search Agent 1.0 for Booyo')
        window.set_title(title)
        # window size setting
	window.set_size_request(500, 412)
	window.set_resizable(False)
	window.set_icon_from_file(self.icons_path)

        main_vbox = gtk.VBox(False, 1)
        main_vbox.set_border_width(1)
        window.add(main_vbox)
        main_vbox.show()

        table = gtk.Table(2,3,False)

        # Create a new notebook, place the position of the tabs
        notebook = gtk.Notebook()
        notebook.set_tab_pos(gtk.POS_TOP)
        table.attach(notebook, 0,6,0,1)
        notebook.show()
        self.show_tabs = True
        self.show_border = True

	# Profile tab
	#profile_tab.tab_create(notebook)
	profile_tab.profile_tab_create(notebook)

	booyoap = gui_ap.BooyoAP(window)
	booyoap_gui = booyoap.init_gui()
	notebook.add(booyoap_gui)
	
	hbox_tmp = gtk.HBox()
	hbox_tmp.show()

	image = gtk.Image()
	image.set_from_stock(gtk.STOCK_FIND, gtk.ICON_SIZE_MENU)
	hbox_tmp.pack_start(image, False, False, 0)
	image.show()

	ap_label = _('AP Search')
        label = gtk.Label(" " + ap_label)
	hbox_tmp.pack_start(label, False, False, 0)
	label.show()

        notebook.set_tab_label(booyoap_gui, hbox_tmp)
	
	#status_tab.tab_create(notebook)

        # Set what page to start at (page 0)
        notebook.set_current_page(0)

        menubar = self.get_main_menu(window)

        main_vbox.pack_start(menubar, False, True, 0)
        menubar.show()

        main_vbox.pack_start(table, False, True, 0)
        table.show()

        window.show()

    # Obligatory basic callback
    def print_about(self, w, data):
	window = gtk.Window(gtk.WINDOW_TOPLEVEL)
	window.set_position(gtk.WIN_POS_CENTER_ALWAYS)
	window.set_border_width(5)
	window.set_size_request(450, 200)
	
	title = _('About')
	window.set_title(title)
	window.set_resizable(False)

	label_about = _("Thank you for used my program!\n"
"Mr.Lee and Mr.Han is developer for haansoft.com\n"
"This program is to make based for Booyo Desktop Linux.\n"
"This program is to help you that search Access Point.\n")
	label=gtk.Label(label_about)
	
	window.add(label)
	
	label.show()
	window.show()

    def print_help(self, w, data):
	window = gtk.Window(gtk.WINDOW_TOPLEVEL)
	window.set_position(gtk.WIN_POS_CENTER_ALWAYS)
	window.set_border_width(3)
	
	title = _('Help')
	window.set_title(title)
	window.resize(150,50)

	help_label = _('Nothing..')
	label = gtk.Label(help_label)
	
	window.add(label)
	
	label.show()
	window.show()

    # 개발시에는 이미지 파일이 들어있지 않기 때문에 개발시와 사용시에 적용될
    # 적절한 패스 설정 방법을 구현 필요
    #icons_path = '../icons/leha-ap.png'
    icons_path = '/usr/share/icons/Booyohaans/48x48/potamia-config-wireless.png'

def main():
    gtk.main()
    return 0

if __name__ == "__main__":
    #profile_tab = gui_profile.TabProfile()
    profile_tab = gui_profile.GuiProfile()
    #status_tab = gui_status.GuiStatus()
    BooyoAPMenu()
    main()

==> potamia-config-wireless-1.1.0.050909.tar.gz: booyo-wireless/frontend/potamia-config-wireless.py <==
#!/usr/bin/env python

import pygtk
pygtk.require('2.0')
import sys
import gtk
import gobject

#PATH = '../'
PATH = '/usr/share/potamia-config-wireless/'

sys.path.append(PATH + 'frontend')
sys.path.append(PATH + 'backend')
import gui_profile
import gui_ap
#import gui_status

PROGNAME='potamia-config-wireless'

import locale
from rhpl.translate import _, N_, textdomain_codeset
locale.setlocale(locale.LC_ALL, "")
textdomain_codeset(PROGNAME, locale.nl_langinfo(locale.CODESET))

import __builtin__
__builtin__.__dict__['_'] = _

class BooyoAPMenu:
    # This is the ItemFactoryEntry structure used to generate new menus.
    # Item 1: The menu path. The letter after the underscore indicates an
    #         accelerator key once the menu is open.
    # Item 2: The accelerator key for the entry
    # Item 3: The callback.
    # Item 4: The callback action.  This changes the parameters with
    #         which the callback is called.  The default is 0.
    # Item 5: The item type, used to define what kind of an item it is.
    #       Here are the possible values:

    #       NULL               -> "<Item>"
    #       ""                 -> "<Item>"
    #       "<Title>"          -> create a title item
    #       "<Item>"           -> create a simple item
    #       "<CheckItem>"      -> create a check item
    #       "<ToggleItem>"     -> create a toggle item
    #       "<RadioItem>"      -> create a radio item
    #       <path>             -> path of a radio item to link against
    #       "<Separator>"      -> create a separator
    #       "<Branch>"         -> create an item to hold sub items (optional)
    #       "<LastBranch>"     -> create a right justified branch 

    def get_main_menu(self, window):
        accel_group = gtk.AccelGroup()

        # This function initializes the item factory.
        # Param 1: The type of menu - can be MenuBar, Menu,
        #          or OptionMenu.
        # Param 2: The path of the menu.
        # Param 3: A reference to an AccelGroup. The item factory sets up
        #          the accelerator table while generating menus.
        item_factory = gtk.ItemFactory(gtk.MenuBar, "<main>", accel_group)

        # This method generates the menu items. Pass to the item factory
        #  the list of menu items
        item_factory.create_items(self.menu_items)

        # Attach the new accelerator group to the window.
        window.add_accel_group(accel_group)

        # need to keep a reference to item_factory to prevent its destruction
        self.item_factory = item_factory
        # Finally, return the actual menu bar created by the item factory.
        return item_factory.get_widget("<main>")

    def __init__(self):
        self.menu_items = (
            ( '/'+_('_File'),         		None,         	None, 0, "<Branch>" ),
            ( '/'+_('_File')+'/'+'sep1',	None,         	None, 0, "<Separator>" ),
            ( '/'+_('_File')+'/'+_('Quit'),     "<control>Q",	gtk.main_quit, 0, None ),
            ( '/'+_('_Help'),      		None,		None, 0, "<Branch>" ),
#            ( "/Help/Help",   			None,         	self.print_help, 0, None ),
#            ( "/Help/sep1",    		None,         	None, 0, "<Separator>" ),
	    ( '/'+_('_Help')+'/'+_('About'),	None,         	self.print_about, 0, None )
#            ( "/About/sep2",    		None,         	None, 0, "<Separator>" ),
#            ( "/About/Version", 		None,         	self.print_version, 0, None ),
            )
        window = gtk.Window(gtk.WINDOW_TOPLEVEL)
	window.set_position(gtk.WIN_POS_CENTER_ALWAYS)
        window.connect("destroy", lambda w: gtk.main_quit())
	# window title name setting
	title = _('AP Search Agent 1.0 for Booyo')
        window.set_title(title)
        # window size setting
	window.set_size_request(500, 412)
	window.set_resizable(False)
	window.set_icon_from_file(self.icons_path)

        main_vbox = gtk.VBox(False, 1)
        main_vbox.set_border_width(1)
        window.add(main_vbox)
        main_vbox.show()

        table = gtk.Table(2,3,False)

        # Create a new notebook, place the position of the tabs
        notebook = gtk.Notebook()
        notebook.set_tab_pos(gtk.POS_TOP)
        table.attach(notebook, 0,6,0,1)
        notebook.show()
        self.show_tabs = True
        self.show_border = True

	# Profile tab
	#profile_tab.tab_create(notebook)
	profile_tab.profile_tab_create(window, notebook)

	booyoap = gui_ap.BooyoAP(window)
	booyoap_gui = booyoap.init_gui()
	notebook.add(booyoap_gui)
	
	hbox_tmp = gtk.HBox()
	hbox_tmp.show()

	image = gtk.Image()
	image.set_from_stock(gtk.STOCK_FIND, gtk.ICON_SIZE_MENU)
	hbox_tmp.pack_start(image, False, False, 0)
	image.show()

	ap_label = _('AP Search')
        label = gtk.Label(" " + ap_label)
	hbox_tmp.pack_start(label, False, False, 0)
	label.show()

        notebook.set_tab_label(booyoap_gui, hbox_tmp)
	
	#status_tab.tab_create(notebook)

        # Set what page to start at (page 0)
        notebook.set_current_page(0)

        menubar = self.get_main_menu(window)

        main_vbox.pack_start(menubar, False, True, 0)
        menubar.show()

        main_vbox.pack_start(table, False, True, 0)
        table.show()

        window.show()

    # Obligatory basic callback
    def print_about(self, w, data):
	window = gtk.Window(gtk.WINDOW_TOPLEVEL)
	window.set_position(gtk.WIN_POS_CENTER_ALWAYS)
	window.set_border_width(5)
	window.set_size_request(450, 200)
	
	title = _('About')
	window.set_title(title)
	window.set_resizable(False)

	label_about = _("Thank you for used my program!\n"
"Mr.Lee and Mr.Han is developer for haansoft.com\n"
"This program is to make based for Booyo Desktop Linux.\n"
"This program is to help you that search Access Point.\n")
	label=gtk.Label(label_about)
	
	window.add(label)
	
	label.show()
	window.show()

    def print_help(self, w, data):
	window = gtk.Window(gtk.WINDOW_TOPLEVEL)
	window.set_position(gtk.WIN_POS_CENTER_ALWAYS)
	window.set_border_width(3)
	
	title = _('Help')
	window.set_title(title)
	window.resize(150,50)

	help_label = _('Nothing..')
	label = gtk.Label(help_label)
	
	window.add(label)
	
	label.show()
	window.show()

    # 개발시에는 이미지 파일이 들어있지 않기 때문에 개발시와 사용시에 적용될
    # 적절한 패스 설정 방법을 구현 필요
    #icons_path = '../icons/leha-ap.png'
    icons_path = '/usr/share/icons/Booyohaans/48x48/potamia-config-wireless.png'

def main():
    gtk.main()
    return 0

if __name__ == "__main__":
    #profile_tab = gui_profile.TabProfile()
    profile_tab = gui_profile.GuiProfile()
    #status_tab = gui_status.GuiStatus()
    BooyoAPMenu()
    main()
